<?php
namespace de\IPSymcon\ernie;

DEFINE ("VAR_BOOLEAN",	0);
DEFINE ("VAR_INTEGER",	1);
DEFINE ("VAR_FLOAT",		2);
DEFINE ("VAR_STRING",	3);

DEFINE ("VARIABLE_CUSTOMACTION" , 	36933);
DEFINE ("VARIABLE_CUSTOMPROFILE", 	"b_Anwesend-Abwesend");

class CreateHeizplan {
	private $configObject;
	private $heizungsKomponenten;

	public function __construct($varConfigObject) {
		$this->configObject = $varConfigObject;
		$this->configObject->showEnvironmentDebugMessage("Object CreateHeizplan erstellt" ,"heizungssteuerung_createHeizplan.class[__construct]",1);

		$this->heizungsKomponenten = new HomeMaticKomponenten($varConfigObject);
	}

	private function checkResult($result,$fehlerText,$scriptName) {
		$createOnlyIPSLogsNOTConsole = FALSE;
		if (!$result) {
			if ($createOnlyIPSLogsNOTConsole) {
				IPS_LogMessage($scriptName, $fehlerText);
				die();
			}
			else {
				die ($fehlerText);
			}
		}
	}

	public function initialize($actualWeekDay) {
		$actualWeekDay -= 1;
		if ($actualWeekDay == 0) {$actualWeekDay = 7;}
		$this->configObject->showEnvironmentDebugMessage('$actualWeekDay == '. $actualWeekDay ,"heizungssteuerung_createHeizplan.class[initialzing]",9);
		// statisch angelegter Test-Tag (0) oder fester Tag der Woche und nicht der vorherige
		// $actualWeekDay = 6;
		// $this->configObject->showEnvironmentDebugMessage('set $actualWeekDay to '. $actualWeekDay ,"heizungssteuerung_createHeizplan.class[initialzing]",9);

		// rootNode des heutigen Tages raussuchen:
		// $this->configObject->showEnvironmentDebugMessage("call  Version: ". $this->configObject->getVersion() ,"createHeizplan.php[initialzing]",1);

		// echo '$IPS_SELF = '. $IPS_SELF . "\n";
		// $actualScript = IPS_GetScript($IPS_SELF);
		// $SCRIPT_ID_NAME = $actualScript['ScriptFile'] ." (". $IPS_SELF .")";
		$SCRIPT_ID_NAME = "createHeizplan.class.ips.php";

		$todayRootNode = $this->configObject->GetRootNodeForDay($actualWeekDay);
		$this->configObject->showEnvironmentDebugMessage('$todayRootNode == '. $actualWeekDay ,"heizungssteuerung_createHeizplan.class[initialzing]",9);
		$now = time();
		$actualHour = date("G");
		$actualMinute = date("i");
		$this->configObject->showEnvironmentDebugMessage('aktuelle Uhrzeit: '. $actualHour .":". $actualMinute ,"heizungssteuerung_createHeizplan.class[initialzing]",9);

		// alte Variablen der vergangenen Woche lschen
		$childrenIDsToday = IPS_GetChildrenIDs($todayRootNode);
		$this->configObject->showEnvironmentDebugMessage("Heizplan vorheriger ". date("l") .":","heizungssteuerung_createHeizplan.class[initialzing]",9);
		for ($i = 0; $i < count($childrenIDsToday); $i++) {
			$actualVariableID = $childrenIDsToday[$i];
			$actualVariableName = IPS_GetName($actualVariableID);
			$this->configObject->showEnvironmentDebugMessage("   ". $actualVariableName ,"heizungssteuerung_createHeizplan.class[initialzing]",9);

			// Variable lschen
			$result = IPS_DeleteVariable($actualVariableID);
			$this->checkResult($result,"die by deleting Vriable ". $actualVariableID ."(". $actualVariableName .")",$SCRIPT_ID_NAME);
			$this->configObject->showEnvironmentDebugMessage(
				 "Variable ". $actualVariableID . " (". $actualVariableName .") erfolgreich gelscht","heizungssteuerung_createHeizplan.class[initialzing]",8);
		}
		
		// neu anzulegende Variablen erstellen:
		$zeitProfile = $this->configObject->getZeitProfile();
		foreach ($zeitProfile as $raumName => $raumValue) {
			// echo "   ". $keyI . "<br>\n";
			foreach ($raumValue as $zeit) {
				// Variable erstellen:
				$variableID = IPS_CreateVariable(VAR_BOOLEAN);
				$this->configObject->showEnvironmentDebugMessage(
					 "Variable ". $variableID . " wurde erstellt","heizungssteuerung_createHeizplan.class[initialzing]",7);

				$variableName = $raumName . " - ". $zeit;
				$result = IPS_SetName($variableID,$variableName);
				$this->checkResult ($result,"die by setting Name to DynamicVariable ". $variableName ,$SCRIPT_ID_NAME);
				$this->configObject->showEnvironmentDebugMessage(
					 "Variable ". $variableID . " umbenannt in: ". $variableName,"heizungssteuerung_createHeizplan.class[initialzing]",7);

				//CustomProfile setzen:
				$result = IPS_SetVariableCustomProfile($variableID,VARIABLE_CUSTOMPROFILE);
				$this->checkResult ($result,"die by setting CustomProfile ". $variableID ." to DynamicVariable ". VARIABLE_CUSTOMPROFILE,$SCRIPT_ID_NAME);
				$this->configObject->showEnvironmentDebugMessage(
					 "Variable ". $variableID . ' CustomProfil : "'. VARIABLE_CUSTOMPROFILE .'" zugewiesen',"heizungssteuerung_createHeizplan.class[initialzing]",7);

				// CustomAktion setzen:
				$result = IPS_SetVariableCustomAction($variableID,VARIABLE_CUSTOMACTION);
				$this->checkResult ($result,"die by setting CustomAction ". $variableID ." to DynamicVariable ". VARIABLE_CUSTOMACTION,$SCRIPT_ID_NAME);
				$this->configObject->showEnvironmentDebugMessage(
					 "Variable ". $variableID . ' CustomAction : "'. VARIABLE_CUSTOMACTION .'" zugewiesen',"heizungssteuerung_createHeizplan.class[initialzing]",7);

				// Variable im Logischen Baum einordnen:
				$result = IPS_SetParent($variableID,$todayRootNode);
				$this->checkResult($result,"die by moving ". $variableID ." to RootNode (". $todayRootNode .")",$SCRIPT_ID_NAME);
				$this->configObject->showEnvironmentDebugMessage(
					"Variable ". $variableID . ' im Baum unter '. $todayRootNode .' ("'. IPS_GetName($todayRootNode) .'") eingeordnet',"heizungssteuerung_createHeizplan.class[initialzing]",7);
					
				// Variable initialisieren:
				$initialValue = $this->configObject->getInitialAnwesendValue($raumName,$zeit,$actualWeekDay);
				$result = SetValueBoolean($variableID,$initialValue);
				$this->checkResult($result,"die by setting ". $variableID ." to ". $initialValue,$SCRIPT_ID_NAME);
				$this->configObject->showEnvironmentDebugMessage(
					"Set Variable ". $variableID . ' to '. $initialValue,"heizungssteuerung_createHeizplan.class[initialzing]",7);


			} // foreach ($raumValue as $zeit)
			echo "<br>\n";

		} // foreach ($zeitProfile as $raumName => $raumValue)

	   IPS_LogMessage("CreateHeizplan.class","Heizplan fr ". IPS_GetName($todayRootNode) ." erfolgreich erstellt");

	} // public function initialize()
} // class CreateHeizplan {


// zum Testen des Script direkt im Editor (Auszug aus heizungssteuerung_aktionsScript-trigger.ips.php):
/*
if (!defined("INCLUDED_HEIZPLAN")) {
	DEFINE("INCLUDED_HEIZPLAN",TRUE);
	}
include("heizungssteuerung_includes.ips.php");
$createHeizplanObject = new CreateHeizplan($configObject);
// $createHeizplanObject->initialize();
*/
?>